require "rubygems"
require "test/unit"
require "test/unit/assertions"
require "prawn"

require "assert_pdf"

class AssertPDFTest < Test::Unit::TestCase
  TEST_FILE = "test.pdf"

  def setup
    Prawn::Document.generate("test.pdf") do |pdf|
      pdf.text "www.qwan.eu"
      pdf.text "Rob"
    end
  end

  def teardown
    File.delete "test.pdf" if File.exist? "test.pdf"
  end

  def test_pdftotext_available
    `pdftotext test.pdf -`
    assert_equal 0, $?.to_i, "pdftotext not installed?"
  end

  def test_assert_non_existing_pdf_fails_test
    assert_raises MiniTest::Assertion do
        assert_pdf "doesnotexist.pdf", :contains => "www.qwan.eu"
    end
  end

  def test_assert_existing_pdf_passes_test
    assert_pdf TEST_FILE, :contains => "www.qwan.eu"
  end

  def test_assert_without_expected_text_raises_error
    assert_raises RuntimeError do
        assert_pdf TEST_FILE, "www.qwan.eu"
    end
  end

  def test_assert_text_not_in_pdf_fails
    assert_raises MiniTest::Assertion do
        assert_pdf TEST_FILE, :contains => "Agile"
    end
  end

  def test_assert_multiple_texts_in_pdf_passes
    assert_pdf TEST_FILE, :contains => ["www.qwan.eu", "Rob"]
  end

  def test_assert_multiple_texts_with_one_not_existing_in_pdf_fails
    assert_raises MiniTest::Assertion do
      assert_pdf TEST_FILE, :contains => ["www.qwan.eu", "agile"]
    end
  end

  def test_asserting_does_non_contain_on_existing_text_fails
    assert_raises MiniTest::Assertion do
      assert_pdf TEST_FILE, :does_not_contain => "www.qwan.eu"
    end
  end
end
