require "test/unit"
require "assert_pdf"
require "qhandout"

class HandoutTest < Test::Unit::TestCase
  def setup
    Handout.new(:course => "TDD For Dummies", :date => "10 June 2031", :location => "Utrecht").create_frontpage
  end

  def teardown
    File.delete "frontpage.pdf" if File.exist? "FrontPage.pdf"
  end

  def test_frontpage_contains_default_trainers
    assert_pdf "frontpage.pdf", :contains => ["Rob", "Tilburg", "Marc", "Willem"]
  end

  def test_frontpage_contains_course_dates_location_footer
    assert_pdf "frontpage.pdf", :contains => ["TDD For Dummies", "10 June 2031", "Utrecht"]
    assert_pdf "frontpage.pdf", :contains => ["2005-2013", "www.qwan.eu"]
  end
end

class TabsTest < Test::Unit::TestCase
  def setup
    @handout = Handout.new :course => "TDD For Dummies", :date => "10 & 11 June 2031", :location => "Utrecht",
      :tabs => [["Intro", "Get to know each other"], ["RDD", "CRC"]]
  end

  def delete_if_exists(files)
    files.each do |file|
      File.delete file if File.exist? file
    end
  end

  def teardown
    delete_if_exists ["toc.pdf", "tab1.pdf", "tab2.pdf"]
  end

  def test_create_toc
    @handout.create_toc

    assert_pdf "toc.pdf", :contains => ["TDD For Dummies"]
    assert_pdf "toc.pdf", :contains => ["1", "Intro", "Get to know each other"]

    assert_pdf "toc.pdf", :contains => ["10 & 11 June 2031", "Utrecht"]
  end

  def test_create_toc_with_multiple_entries
    @handout.create_toc

    assert_pdf "toc.pdf", :contains => ["1", "Intro", "Get to know each other"]
    assert_pdf "toc.pdf", :contains => ["2", "TDD", "CRC"]
  end

  def test_create_tab_page
    @handout.create_tabs

    assert_pdf "tab1.pdf", :contains => ["1", "Intro", "Get to know each other"]

    assert_pdf "tab1.pdf", :contains => ["10 & 11 June 2031", "Utrecht"]
  end

  def test_create_multiple_tab_pages
    @handout.create_tabs

    assert_pdf "tab2.pdf", :contains => ["2", "RDD", "CRC"]
    assert_pdf "tab2.pdf", :does_not_contain => "Intro"
  end
end
